Introduction
============

The `rsyslog <http://rsyslog.com/>`_ package is used to read, process, store
and forward system logs in different ways, on local or remote systems. The
``debops.rsyslog`` role can be used to easily configure log forwarding to
a central log server, as well as store logs on the filesystem or other storage
backends.

Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.0.0``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.rsyslog

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
